
.. automodule:: bci_framework.framework.editor
   :members:
   :no-undoc-members:
   :no-show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bci_framework.framework.editor.highlighters

Submodules
----------

.. toctree::
   :maxdepth: 4

   bci_framework.framework.editor.completer
   bci_framework.framework.editor.editor
   bci_framework.framework.editor.snippets
